API Reference
=============

.. currentmodule:: pyswrd


Functions
---------

.. autofunction:: pyswrd.search


Classes
-------

.. toctree::
   :hidden:

   Kmer Generator <kmer_generator>
   Scorer <scorer>
   E-value <evalue>
   Sequences <sequences>
   Filter Score <filter_score>
   Filter Result <filter_result>
   Heuristic Filter <heuristic_filter>
   Hit <hit>


.. only:: html

    .. autosummary::
        :nosignatures:

        pyswrd.KmerGenerator
        pyswrd.Scorer
        pyswrd.EValue
        pyswrd.Sequences
        pyswrd.FilterScore
        pyswrd.FilterResult
        pyswrd.HeuristicFilter
        pyswrd.Hit
